@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,10 +34,9 @@ from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.metastore_v1alpha.services.dataproc_metastore import pagers
 from google.cloud.metastore_v1alpha.types import metastore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import DataprocMetastoreTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import DataprocMetastoreGrpcTransport
 from .transports.grpc_asyncio import DataprocMetastoreGrpcAsyncIOTransport
@@ -62,7 +59,7 @@ class DataprocMetastoreClientMeta(type):
     def get_transport_class(
         cls, label: str = None,
     ) -> Type[DataprocMetastoreTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -108,7 +105,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -142,7 +140,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -159,7 +158,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -178,23 +177,24 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @property
     def transport(self) -> DataprocMetastoreTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            DataprocMetastoreTransport: The transport used by the client instance.
+            DataprocMetastoreTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def backup_path(project: str, location: str, service: str, backup: str,) -> str:
-        """Return a fully-qualified backup string."""
+        """Returns a fully-qualified backup string."""
         return "projects/{project}/locations/{location}/services/{service}/backups/{backup}".format(
             project=project, location=location, service=service, backup=backup,
         )
 
     @staticmethod
     def parse_backup_path(path: str) -> Dict[str, str]:
-        """Parse a backup path into its component segments."""
+        """Parses a backup path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/services/(?P<service>.+?)/backups/(?P<backup>.+?)$",
             path,
@@ -205,7 +205,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     def metadata_import_path(
         project: str, location: str, service: str, metadata_import: str,
     ) -> str:
-        """Return a fully-qualified metadata_import string."""
+        """Returns a fully-qualified metadata_import string."""
         return "projects/{project}/locations/{location}/services/{service}/metadataImports/{metadata_import}".format(
             project=project,
             location=location,
@@ -215,7 +215,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def parse_metadata_import_path(path: str) -> Dict[str, str]:
-        """Parse a metadata_import path into its component segments."""
+        """Parses a metadata_import path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/services/(?P<service>.+?)/metadataImports/(?P<metadata_import>.+?)$",
             path,
@@ -224,14 +224,14 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def network_path(project: str, network: str,) -> str:
-        """Return a fully-qualified network string."""
+        """Returns a fully-qualified network string."""
         return "projects/{project}/global/networks/{network}".format(
             project=project, network=network,
         )
 
     @staticmethod
     def parse_network_path(path: str) -> Dict[str, str]:
-        """Parse a network path into its component segments."""
+        """Parses a network path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/global/networks/(?P<network>.+?)$", path
         )
@@ -239,14 +239,14 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def service_path(project: str, location: str, service: str,) -> str:
-        """Return a fully-qualified service string."""
+        """Returns a fully-qualified service string."""
         return "projects/{project}/locations/{location}/services/{service}".format(
             project=project, location=location, service=service,
         )
 
     @staticmethod
     def parse_service_path(path: str) -> Dict[str, str]:
-        """Parse a service path into its component segments."""
+        """Parses a service path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/services/(?P<service>.+?)$",
             path,
@@ -255,7 +255,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -268,7 +268,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -279,7 +279,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -290,7 +290,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -301,7 +301,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -315,12 +315,12 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, DataprocMetastoreTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the dataproc metastore client.
+        """Instantiates the dataproc metastore client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -375,9 +375,10 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -389,12 +390,14 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -409,8 +412,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -449,7 +452,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -481,10 +483,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.ListServicesRequest):
             request = metastore.ListServicesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -534,7 +534,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -563,10 +562,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.GetServiceRequest):
             request = metastore.GetServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -637,7 +634,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``service_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -669,10 +665,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.CreateServiceRequest):
             request = metastore.CreateServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if service is not None:
@@ -709,7 +703,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: metastore.UpdateServiceRequest = None,
         *,
         service: metastore.Service = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -741,7 +735,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -773,10 +766,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.UpdateServiceRequest):
             request = metastore.UpdateServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if service is not None:
                 request.service = service
             if update_mask is not None:
@@ -832,7 +823,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -874,10 +864,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.DeleteServiceRequest):
             request = metastore.DeleteServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -898,7 +886,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=metastore.OperationMetadata,
         )
 
@@ -929,7 +917,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -961,10 +948,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.ListMetadataImportsRequest):
             request = metastore.ListMetadataImportsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1014,7 +999,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1043,10 +1027,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.GetMetadataImportRequest):
             request = metastore.GetMetadataImportRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1116,7 +1098,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``metadata_import_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1148,10 +1129,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.CreateMetadataImportRequest):
             request = metastore.CreateMetadataImportRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if metadata_import is not None:
@@ -1188,7 +1167,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         request: metastore.UpdateMetadataImportRequest = None,
         *,
         metadata_import: metastore.MetadataImport = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1222,7 +1201,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1254,10 +1232,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.UpdateMetadataImportRequest):
             request = metastore.UpdateMetadataImportRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if metadata_import is not None:
                 request.metadata_import = metadata_import
             if update_mask is not None:
@@ -1303,7 +1279,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
             request (google.cloud.metastore_v1alpha.types.ExportMetadataRequest):
                 The request object. Request message for
                 [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1alpha.DataprocMetastore.ExportMetadata].
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1320,7 +1295,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a metastore.ExportMetadataRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1386,7 +1360,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``backup`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1418,10 +1391,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.RestoreServiceRequest):
             request = metastore.RestoreServiceRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if service is not None:
                 request.service = service
             if backup is not None:
@@ -1475,7 +1446,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1507,10 +1477,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.ListBackupsRequest):
             request = metastore.ListBackupsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1560,7 +1528,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1587,10 +1554,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.GetBackupRequest):
             request = metastore.GetBackupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1657,7 +1622,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``backup_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1689,10 +1653,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.CreateBackupRequest):
             request = metastore.CreateBackupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if backup is not None:
@@ -1748,7 +1710,6 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1790,10 +1751,8 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         # there are no flattened fields.
         if not isinstance(request, metastore.DeleteBackupRequest):
             request = metastore.DeleteBackupRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1814,7 +1773,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=metastore.OperationMetadata,
         )
 
